from deprecated import deprecated

from specklepy.api.resources import ServerResource
from specklepy.core.api.models.deprecated import FE1_DEPRECATION_VERSION


@deprecated(reason="Renamed to ServerResource", version=FE1_DEPRECATION_VERSION)
class Resource(ServerResource):
    """Renamed to ServerResource"""



from typing import Optional, Sequence

from pydantic import BaseModel


class UserUpdateInput(BaseModel):
    avatar: Optional[str] = None
    bio: Optional[str] = None
    company: Optional[str] = None
    name: Optional[str] = None


class UserProjectsFilter(BaseModel):
    search: str
    onlyWithRoles: Optional[Sequence[str]] = None
